@@ -203,11 +203,14 @@ fit_enorm_ = function(dataSrc, qtpredicate = NULL, fixed_params = NULL, method=c
     message('Hessian matrix could not be inverted due to lack of computable precision. Bayesian method was used.')
   }
   
+  b=result$b
+  if(is.matrix(b))
+    b=colMeans(b)
   
   mle = design %>% 
     group_by(.data$booklet_id) %>%
     do({
-      est = theta_MLE(result$b, a=ssIS$item_score, .$first, .$last, se=FALSE)
+      est = theta_MLE(b, a=ssIS$item_score, .$first, .$last, se=FALSE)
       theta = est$theta[2:(length(est$theta)-1)]
       tibble(booklet_score=1:length(theta), theta = theta)
     }) %>%
@@ -402,45 +405,68 @@ print.prms = function(x, ...){
 #' @param object an enorm parameters object, generated by the function \code{\link{fit_enorm}}
 #' @param hpd width of Bayesian highest posterior density interval around mean_beta, 
 #'  value must be between 0 and 1, default is 0.95 
+#' @param what which coefficients to return. Defaults to `items` (the item parameters). Can also be `var` for the 
+#' variance-covariance matrix (CML only) or `posterior` for all draws of the item parameters (Bayes only)  
 #' @param ... further arguments to coef are ignored
 #'  
 #' @return 
-#' Depends on the calibration method:
+#' Depends on the calibration method and the value of 'what'. For 'items'#' 
+#' 
 #' \describe{
-#' \item{for CML}{a data.frame with columns: item_id, item_score, beta, SE_beta}
-#' \item{for Bayes}{a data.frame with columns: item_id, item_score, mean_beta, SD_beta, -bayes_hpd_b_left-, -bayes_hpd_b_right-}
+#' \item{CML}{a data.frame with columns: item_id, item_score, beta, SE_beta}
+#' \item{Bayes}{a data.frame with columns: item_id, item_score, mean_beta, SD_beta, <hpd_b_left>, <hpd_b_right>}
 #' }
 #' 
+#' The posterior distribution and variance covariance matrix are returned as matrices.
 #' 
 #' 
-coef.prms = function(object, hpd = 0.95, ...)
+#' 
+coef.prms = function(object, hpd = 0.95, what=c('items','var','posterior'), ...)
 {
   x = object
+  what = match.arg(what)
   
-  if (x$inputs$method=="CML")
+  if(what=='items')
   {
-    atab=data.frame(item_id=x$inputs$ssIS$item_id[-x$inputs$ssI$first],
-                    item_score=as.integer(x$inputs$ssIS$item_score[-x$inputs$ssI$first]),
-                    beta=x$est$beta,
-                    SE_beta=sqrt(diag(x$est$acov.beta)),stringsAsFactors=FALSE)
-  } else
+    if (x$inputs$method=="CML")
+    {
+      atab=data.frame(item_id=x$inputs$ssIS$item_id[-x$inputs$ssI$first],
+                      item_score=as.integer(x$inputs$ssIS$item_score[-x$inputs$ssI$first]),
+                      beta=x$est$beta,
+                      SE_beta=sqrt(diag(x$est$acov.beta)),stringsAsFactors=FALSE)
+    } else
+    {
+      if(hpd <= 0 ||  hpd >= 1)
+        stop('hpd must be between 0 and 1')
+      
+      hh = t(apply(x$est$beta,2,hpdens, conf=hpd))
+      atab=data.frame(item_id = x$inputs$ssIS$item_id[-x$inputs$ssI$first],
+                      a = x$inputs$ssIS$item_score[-x$inputs$ssI$first],
+                      mb = colMeans(x$est$beta),
+                      sdb = apply(x$est$beta, 2, sd),
+                      hpdl = hh[,1], hpdr=hh[,2],stringsAsFactors=FALSE)
+      colnames(atab)=c("item_id" ,"item_score", "mean_beta", "SD_beta", 
+                       sprintf("%i_hpd_b_left", round(100 * hpd)),
+                       sprintf("%i_hpd_b_right", round(100 * hpd)))
+    }
+    atab$item_id = as.character(atab$item_id)
+    rownames(atab) = NULL
+    return(df_format(atab))
+  } else if(what=='var')
   {
-    if(hpd <= 0 ||  hpd >= 1)
-      stop('hpd must be between 0 and 1')
-    
-    hh = t(apply(x$est$beta,2,hpdens, conf=hpd))
-    atab=data.frame(item_id = x$inputs$ssIS$item_id[-x$inputs$ssI$first],
-                    a = x$inputs$ssIS$item_score[-x$inputs$ssI$first],
-                    mb = colMeans(x$est$beta),
-                    sdb = apply(x$est$beta, 2, sd),
-                    hpdl = hh[,1], hpdr=hh[,2],stringsAsFactors=FALSE)
-    colnames(atab)=c("item_id" ,"item_score", "mean_beta", "SD_beta", 
-                     sprintf("%i_hpd_b_left", round(100 * hpd)),
-                     sprintf("%i_hpd_b_right", round(100 * hpd)))
+    if(x$inputs$method!="CML")
+      stop('Variance-covariance matrix is only available for CML extimation')
+    m = x$est$acov.beta
+    colnames(m) = rownames(m) = paste(x$inputs$ssIS$item_id, x$inputs$ssIS$item_score)[-x$inputs$ssI$first]
+    return(m)
+  } else if(what=='posterior')
+  {
+    if(x$inputs$method!="Bayes")
+      stop('The posterior of item parameters is only available for Bayesian estimation')
+    m=x$est$beta
+    colnames(m) = paste(x$inputs$ssIS$item_id, x$inputs$ssIS$item_score)[-x$inputs$ssI$first]
+    return(m)
   }
-  atab$item_id = as.character(atab$item_id)
-  rownames(atab) = NULL
-  df_format(atab)
 }
 
 
